vorespuls.dk — inspiration til din træning
Description: vorespuls.dk - inspiration til din træning

inspiration til din træning

- Log ind
- eller Opret bruger

Brugernavn: *
Adgangskode: *
Glemt kodeord?
Connect Sign in using Facebook
Søg på dette site:

### Se alle events i februar - MTB, trail, walk-a-thon?

Få en komplet liste over alle events i februar på vorespuls.dk

Læs mere

### Sprinttræning til en hurtigere 5 km'er

Vil du gerne blive bedre på din 5-kilometer, så er sprinttræning en rigtig god metode.

Læs mere

### Bloddonor? Så lang tid går der, før kroppen er klar igen

Få svaret på, hvornår din krop er tilbage i topform, efter du har givet blod.

Læs mere

## Gratis træningsprogram

Få program på mail

Få motivation til din træning

## Sådan foregår en dopingkontrol

Dopingkontrol

Hvis du træner i et motionscenter, så kan du faktisk blive dopingtestet.

## TEMA I JANUAR: LØB NYTÅRSFORSÆTTET IGANG

## Løbeprogram: 7 gratis træningsprogrammer

Find det træningsprogram i løb, der passer til dig.

## Løb om vinteren – ALT du skal vide

Kom ud i vinteren

Alt, der er værd at vide om løb i vinterperioden.

## Løb sikkert i mørke

På med releksen

Se 8 tips til løb i mørke

## Løb en hurtig 5 km´er

træningspas

Se her, hvordan du skal træne

## Guide: Løbebånd med eller uden stigning?

Stigning eller ej?

Her er gode råd til, om du skal have stigning på løbebåndet eller ej.

## 5 forslag til din næste MTB-rejse

Kom ud i verden på MTB

Her er 5 bud på steder i verden, hvor du kan udfordre dig selv på MTB.

## Seneste spørgsmål

- Triatlon: hvordan træner jeg til en duathlon Seneste svar af: emilfloche
- Livsstil: Sammensat træningsprogram Seneste svar af: jhjorsal, emilfloche
- Cykling: mine ruter Ingen svar

## Populære artikler

- Løbeprogram: 7 gratis træningsprogrammer
- Sådan løber du 10-20-30-løb
- Løb: 3 metoder til intervaltræning

Vis seneste artikler

## 4 gode råd: Få svømme-motivation tilbage

svømme-motivation

Få 4 gode råd fra vores svømme-ekspert, til at finde motivationen igen.

## Nyt koncept: Gå et maraton i Danmark

Walk-a-thon

Er 42,195 kilometer i overkanten at løbe – hvorfor så ikke prøve at gå det?

## Tilmeld nyhedsbreve

Vælg nyhedsbreve

Generelle nyheder
Løb
Svømning
Kajak
Cykling & MTB
Navn (frivillig):
E-mail: *
Leave this field blank:
Læs seneste nyhedsbreve
vorespuls.dk

Find event
- udfordringer på dit niveau
Løb
Triatlon
Cykling
MTB
Svømning
Kajak
Livsstil
Dato
Format: 01-02-2016

## Tilføj din egen event

Du kan nemt og gratis oprette din event og få den vist på vorespuls.dk. Opret event

##

Kommende events

1
Feb

- MTB

MTB mekaniker kursus
18:30 Horsens
Myter aflives og erstattes med fakta ;-)...
3
Feb

- Cykling
- MTB

Mekanikerkursus - kun for kvinder
19:00 Rødovre
Er du også en entusiastisk motionist, som...
5
Feb

- MTB

MTB weekend
18:00 Fjerritslev
Mountainbike weekend for ryttere på alle...
6
Feb

- Løb

DGI Sydvest Crossløbs-serien - 3. afd.
14:00 Esbjerg V
Høj puls hele vinteren! Styrk formen og grib...
7
Feb

- Løb

Molboløbet 6
9:00 Nærum
Orienteringsløb for alle med spørgsmål på...

## Din mening tæller

Har du ris eller ros til os, så hører vi gerne fra dig.

Send en besked

vorespuls.dk
vorespuls.dk drives af:

- DGI
- Nykredit

©2012 Nykredit/DGI
Leave this field blank: